@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
 # Copyright 2011,2013 Christoph Reiter
-#                2016 Nick Boultbee
+#             2016-22 Nick Boultbee
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -9,8 +8,7 @@
 
 from gi.repository import Gtk, Pango, GLib
 
-from quodlibet import _
-from quodlibet.compat import listfilter
+from quodlibet import _, util
 from quodlibet.qltk import Button, Window
 from quodlibet.util import connect_obj, print_w
 
@@ -37,7 +35,7 @@ def can_submit(result):
 
 class FingerprintDialog(Window):
     def __init__(self, songs):
-        super(FingerprintDialog, self).__init__()
+        super().__init__()
         self.set_border_width(12)
         self.set_title(_("Submit Acoustic Fingerprints"))
         self.set_default_size(450, 0)
@@ -47,7 +45,7 @@ class FingerprintDialog(Window):
         box = Gtk.VBox(spacing=6)
 
         self.__label = label = Gtk.Label()
-        label.set_markup("<b>%s</b>" % _("Generating fingerprints:"))
+        label.set_markup(util.bold(_("Generating fingerprints:")))
         label.set_alignment(0, 0.5)
         box.pack_start(label, False, True, 0)
 
@@ -112,20 +110,20 @@ class FingerprintDialog(Window):
     def __update_stats(self):
         all_ = len(self.__songs)
         results = self.__fp_results.values()
-        to_send = len(listfilter(can_submit, results))
+        to_send = len(list(filter(can_submit, results)))
         valid_fp = len(results)
         got_mbid, got_meta = get_stats(results)
 
         text = _("Songs either need a <i><b>musicbrainz_trackid</b></i>, "
-            "or <i><b>artist</b></i> / "
-            "<i><b>title</b></i> / <i><b>album</b></i> tags to get submitted.")
-        text += "\n\n" + "<i>%s</i>" % _("Fingerprints:")
+                 "or <i><b>artist</b></i> / "
+                 "<i><b>title</b></i> / <i><b>album</b></i> tags to get submitted.")
+        text += "\n\n" + util.italic(_("Fingerprints:"))
         text += " %d/%d" % (valid_fp, all_)
-        text += "\n" + "<i>%s</i>" % _("Songs with MBIDs:")
+        text += "\n" + util.italic(_("Songs with MBIDs:"))
         text += " %d/%d" % (got_mbid, all_)
-        text += "\n" + "<i>%s</i>" % _("Songs with sufficient tags:")
+        text += "\n" + util.italic(_("Songs with sufficient tags:"))
         text += " %d/%d" % (got_meta, all_)
-        text += "\n" + "<i>%s</i>" % _("Songs to submit:")
+        text += "\n" + util.italic(_("Songs to submit:"))
         text += " %d/%d" % (to_send, all_)
         self.__stats.set_markup(text)
 
@@ -179,7 +177,7 @@ class FingerprintDialog(Window):
 
     def __submit_cb(self, *args):
         self.__submit.set_sensitive(False)
-        self.__label.set_markup("<b>%s</b>" % _("Submitting fingerprints:"))
+        self.__label.set_markup(util.bold(_("Submitting fingerprints:")))
         self.__set_fraction(0)
         self.__acoustid_thread = AcoustidSubmissionThread(
             list(filter(can_submit, self.__fp_results.values())),
@@ -187,7 +185,7 @@ class FingerprintDialog(Window):
 
     def __acoustid_update(self, progress):
         self.__set_fraction(progress)
-        self.__label_song.set_text(_(u"Submitting…"))
+        self.__label_song.set_text(_("Submitting…"))
 
     def __acoustid_done(self):
         self.__acoustid_thread.join()
