@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2015 Christoph Reiter
 #
 # This program is free software; you can redistribute it and/or modify
@@ -25,7 +24,7 @@ class Priority(int):
     BACKGROUND = 1
 
 
-class Cancellable(object):
+class Cancellable:
     """Subset of Gio.Cancellable so it can be used as well"""
 
     def __init__(self):
